@@ -7,17 +7,75 @@ use FLAT::DFA;
 use Carp;
 
 use vars '$VERSION';
-$VERSION = 0.9;
+$VERSION = q{1.0.O};
 
 =head1 NAME
 
 FLAT - Formal Language & Automata Toolkit
 
+=head2 Name Change Possibility
+
+Future releases of this module may very well reflect a name change that is considered
+to me more I<normal> for Perl modules. When this was originally written (2006), the
+original author was not very well versed in the idiomatic aspects of C<PERL>.
+
 =head1 SYNOPSIS
 
 FLAT.pm is the base class of all regular language objects. For more
 information, see other POD pages.
 
+=head1 DESCRIPTION
+
+This module provides an interface for manipulating the formal language
+concept of Regular Expressions, which are used to describe Regular Languages,
+and their equivalent forms of Automata.
+
+It's notable that this module supports, in addition to the traditional Regular
+Expression operators, the C<shuffle> operator (see [1]). This is expressed as an ampersand,
+C<&>. In addition to this, logical symbols may be multiple characters. This leads
+to some interesting applications.
+
+While the module can do a lot, i.e.:
+
+=over 4
+
+=item * parse a regular expression (RE) (of the formal regular language variety) 
+
+=item * convert a RE to a NFA (and similarly, a I<shuffle> of two regular languages
+to a I<parallel> NFA (PFA))
+
+=item * convert a PFA to a NFA (note, PFAs are equivalent to PetriNets (see [2], L<Graph::PetriNet>)
+
+=item * convert a NFA to a DFA
+
+=item * convert a DFA to a minimal DFA
+
+=item * generate strings that may be accepted by a DFA
+
+=back
+
+It is still missing some capabilities that one would expect:
+
+=over 4
+
+=item * generate equivalent REs from a NFA or DFA
+
+=item * provide targeted conversion of PFAs, NFAs, DFAs to their more explicit state forms; this
+is particularly interested to have in the case of the PFA.
+
+=item * provide targeted serialization of PREs (REs with a shuffle) using direct, explicit manuplation of the AST produced by the parser
+
+=item * provide other interesting graph-based manipulations that might prove useful, particular when applied to a graph that represents some form of a finite automata (FA)
+
+=back
+
+In addition to the above deficiencies, application of this toolkit in interesting areas would
+naturally generate ideas for new and interesting capabilities.
+
+=head2 Sequential Consistency and PREs
+
+Valid strings accepted by the shuffle of one or more regular languages is necessarily I<sequentially consistent>. This results from the conversions to a DFA that may be traversed inorder to discover valid string paths necessarily obeys the total ordering constraints of each constituent language of the two being shuffled; and the partial ordering that results among valid string accepted by both (see [2] for more on how PetriNets fit in).
+
 =head1 USAGE
 
 All regular language objects in FLAT implement the following methods.
@@ -191,17 +249,20 @@ represented by $lang.
 
 =head1 AUTHORS & ACKNOWLEDGEMENTS
 
-FLAT is written by Mike Rosulek E<lt>mike at mikero dot comE<gt> and Brett 
-Estrade E<lt>estradb at gmail dot comE<gt>.
-
-The initial version (FLAT::Legacy) by Brett Estrade was work towards an MS 
-thesis at the University of Southern Mississippi.
+FLAT is written by Mike Rosulek E<lt>mike at mikero dot comE<gt> and B. 
+Estarde E<lt>estradb at gmail dot comE<gt>.
 
 =head1 LICENSE
 
 This module is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
-=head1 MORE INFO
+=head1 REFERENCES
 
-Please visit the Wiki at http://www.0x743.com/flat
+=over 4
+
+=item 1. C<Introduction to Automata Theory, Languages, and Computation>; John E. Hopcroft, Rajeev Motwani, Jeffrey D. Ullman
+
+=item 2. C<Parallel Finite Automata for Modeling Concurrent Software Systems>;  P. David Stotts , William Pugh 
+
+=back
